@@ -160,8 +160,8 @@ class GreedyAcquisitionFunctionBuilder(Generic[T], ABC):
     """
     A :class:`GreedyAcquisitionFunctionBuilder` builds an acquisition function
     suitable for greedily building batches for batch Bayesian
-    Optimization. :class:`GreedyAcquisitionFunctionBuilder` differs
-    from :class:`AcquisitionFunctionBuilder` by requiring that a set
+    Optimization. A :class:`GreedyAcquisitionFunctionBuilder` differs
+    from an :class:`AcquisitionFunctionBuilder` by requiring that a set
     of pending points is passed to the builder. Note that this acquisition function
     is typically called `B` times each Bayesian optimization step, when building batches
     of size `B`.
@@ -304,6 +304,55 @@ class SingleModelGreedyAcquisitionBuilder(Generic[T], ABC):
         )
 
 
+class VectorizedAcquisitionFunctionBuilder(AcquisitionFunctionBuilder[T]):
+    """
+    An :class:`VectorizedAcquisitionFunctionBuilder` builds and updates a vectorized
+    acquisition function These differ from normal acquisition functions only by their output shape:
+    rather than returning a single value, they return one value per potential query point.
+    Thus, with leading dimensions, they take input shape `[..., B, D]` and returns shape `[..., B]`.
+    """
+
+
+class SingleModelVectorizedAcquisitionBuilder(SingleModelAcquisitionBuilder[T]):
+    """
+    Convenience acquisition function builder for vectorized acquisition functions (or component
+    of a composite vectorized acquisition function) that requires only one model, dataset pair.
+    """
+
+    def using(self, tag: str) -> AcquisitionFunctionBuilder[T]:
+        """
+        :param tag: The tag for the model, dataset pair to use to build this acquisition function.
+        :return: An acquisition function builder that selects the model and dataset specified by
+            ``tag``, as defined in :meth:`prepare_acquisition_function`.
+        """
+        single_builder = self
+
+        class _Anon(VectorizedAcquisitionFunctionBuilder[T]):
+            def prepare_acquisition_function(
+                self,
+                models: Mapping[str, T],
+                datasets: Optional[Mapping[str, Dataset]] = None,
+            ) -> AcquisitionFunction:
+                return single_builder.prepare_acquisition_function(
+                    models[tag], dataset=None if datasets is None else datasets[tag]
+                )
+
+            def update_acquisition_function(
+                self,
+                function: AcquisitionFunction,
+                models: Mapping[str, T],
+                datasets: Optional[Mapping[str, Dataset]] = None,
+            ) -> AcquisitionFunction:
+                return single_builder.update_acquisition_function(
+                    function, models[tag], dataset=None if datasets is None else datasets[tag]
+                )
+
+            def __repr__(self) -> str:
+                return f"{single_builder!r} using tag {tag!r}"
+
+        return _Anon()
+
+
 PenalizationFunction = Callable[[TensorType], TensorType]
 """
 An :const:`PenalizationFunction` maps a query point (of dimension `D`) to a single
